SkillListInput class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
schemaFields
→ List <CliParam >
The command's declared parameter contract. Returns null by default —
an Input that declares none is not enforced and is described in help by
its route and description alone.
no setter
selection
→ Selection
final
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson ()
→ Map <String , dynamic >
Serialize the input payload to a JSON-encodable map.
toString ()
→ String
A string representation of this object.
inherited